@@ -1,5 +1,13 @@
 import logging
 
+_DBNAME_MAP = {
+    'psycopg2': 'postgres',
+    'MySQLdb': 'mysql',
+    'sqlite3': 'sqlite',
+    'sqlite': 'sqlite',
+    'pysqlite2': 'sqlite'
+    }
+
 ITEM_LIMIT = 1000
 PARAMTOKEN = '%s'
 PK_ID = 'id'
@@ -99,6 +107,19 @@ class DelayedSqlExecutor(object):
 
         to.add(values)
 
+    # thanks to http://stackoverflow.com/users/538718/samplebias for this solution to find database type.
+    def get_dbname(self):
+        assert(hasattr(self.cursor, 'connection'), \
+               'cursor object does not have a connection attribute. Cannot determine database type without it.')
+        mod = self.cursor.connection.__class__.__module__.split('.', 1)[0]
+        return _DBNAME_MAP.get(mod)
+
+    def quote(self, field):
+        # So far I only know of postgres who needs this, sqlite and mysql supposedly works with the default quoting
+        if self.get_dbname() == 'postgres':
+            return '"%s"' % field
+        return '`%s`' % field
+        
     def execute_sql(self):
         for k,v in self.registered_objects.items():
             tablename = self.registered_objects[k].tablename
@@ -183,7 +204,7 @@ class DelayedSqlExecutor(object):
             if v.insert_items:
                 fieldnames = []                
                 sql = 'insert into %s (%s) values (%s)' % \
-                    (v.tablename, ', '.join(['`%s`' % f for f in v.fields if f != v.pk]), ', '.join([self.paramtoken for f in v.fields if f != v.pk]))
+                    (v.tablename, ', '.join([self.quote(f) % f for f in v.fields if f != v.pk]), ', '.join([self.paramtoken for f in v.fields if f != v.pk]))
                 fieldvalues = []
                 for items in v.insert_items:
                     self.records_processed += 1
@@ -303,6 +324,7 @@ def model_to_dict(obj, exclude_models=['AutoField', 'ForeignKey', \
             tree[field_name] = value
  
     return tree
+
 def get_defaultvalue_for_field_from_model(model, field):
     """
     Get default value, if any, for a specified field in a specified model.
@@ -439,6 +461,8 @@ class _ModelFactory:
         
         self.models = []
         for model in get_models():
+            #if not model._meta.managed:
+            #    continue
             dex = ModelDelayedExecutor(model)
             setattr(self, model._meta.object_name, dex)
             setattr(model, 'dse', dex)
@@ -458,4 +482,4 @@ class _ModelFactory:
         return self
 
 if DJANGO_SUPPORT and not 'ModelFactory' in dir():
-    ModelFactory = _ModelFactory()
\ No newline at end of file
+    ModelFactory = _ModelFactory()
